@@ -11,14 +11,15 @@ from .parser import Parser
 if TYPE_CHECKING:
     from nonebot.adapters import Message
 
-__version__ = version('nonebot_plugin_strman')
-
-logger.info(f'Plugin loaded: nonebot_plugin_strman v{__version__}')
+__version__ = version("nonebot_plugin_strman")
+logger.success(f"Plugin loaded: <b>NoneBot String Manager v{__version__}</b>")
 
 
 @export()
-def init(impl: Optional[Type['Message']] = None,
-         **config: Union[NBConfig, Dict[str, Any], str]) -> Parser:
+def init(
+    impl: Optional[Type["Message"]] = None,
+    **config: Union[NBConfig, Dict[str, Any], str],
+) -> Parser:
     """
     创建解析器对象。
 
@@ -31,21 +32,18 @@ def init(impl: Optional[Type['Message']] = None,
     """
     if not config:
         parser = Parser(impl)
-    elif (_config := config.pop('config', None)):
+    elif _config := config.pop("config", None):
         if isinstance(_config, dict):
             parser = Parser(impl, **_config)
         elif isinstance(_config, NBConfig):
             parser = Parser(impl, **_config.dict())
         else:
-            raise ValueError('Invalid config type')
+            raise ValueError("Invalid config type")
     else:
         conf_attr = {
-            'strman_respath': config.pop('respath', None),
-            'strman_profile': config.pop('profile', None)
+            "strman_respath": config.pop("respath", None),
+            "strman_profile": config.pop("profile", None),
         }
-        parser = Parser(
-            impl, **{k: v
-                     for k, v in conf_attr.items()
-                     if v is not None})
+        parser = Parser(impl, **{k: v for k, v in conf_attr.items() if v is not None})
 
     return parser
